==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/CustomPaletteBrushScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { CustomPaletteBrushScaleDescription } from "./CustomPaletteBrushScaleDescription";
/**
 * @hidden
 */
var CustomPaletteBrushScaleDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CustomPaletteBrushScaleDescriptionMetadata, _super);
    function CustomPaletteBrushScaleDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomPaletteBrushScaleDescriptionMetadata.b = function (a) {
        if (CustomPaletteBrushScaleDescriptionMetadata.a == null) {
            CustomPaletteBrushScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CustomPaletteBrushScaleDescriptionMetadata.c(CustomPaletteBrushScaleDescriptionMetadata.a);
        }
        if (a.g(CustomPaletteBrushScaleDescriptionMetadata.a)) {
            return;
        }
        a.s(CustomPaletteBrushScaleDescriptionMetadata.a);
    };
    CustomPaletteBrushScaleDescriptionMetadata.c = function (a) {
        BrushScaleDescriptionMetadata.c(a);
        a.item("BrushSelectionMode", "ExportedType:string:BrushSelectionMode");
        a.item("BrushSelectionMode@names", "Select;Interpolate");
    };
    CustomPaletteBrushScaleDescriptionMetadata.d = function (a) {
        CustomPaletteBrushScaleDescriptionMetadata.b(a);
        a.u("CustomPaletteBrushScale", function () { return new CustomPaletteBrushScaleDescription(); });
        a.t("CustomPaletteBrushScale", CustomPaletteBrushScaleDescriptionMetadata.a);
    };
    CustomPaletteBrushScaleDescriptionMetadata.$t = markType(CustomPaletteBrushScaleDescriptionMetadata, 'CustomPaletteBrushScaleDescriptionMetadata');
    CustomPaletteBrushScaleDescriptionMetadata.a = null;
    return CustomPaletteBrushScaleDescriptionMetadata;
}(Base));
export { CustomPaletteBrushScaleDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CustomPaletteBrushScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { CustomPaletteBrushScaleDescription } from "./CustomPaletteBrushScaleDescription";
/**
 * @hidden
 */
var CustomPaletteBrushScaleDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CustomPaletteBrushScaleDescriptionMetadata, _super);
    function CustomPaletteBrushScaleDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomPaletteBrushScaleDescriptionMetadata.b = function (a) {
        if (CustomPaletteBrushScaleDescriptionMetadata.a == null) {
            CustomPaletteBrushScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CustomPaletteBrushScaleDescriptionMetadata.c(CustomPaletteBrushScaleDescriptionMetadata.a);
        }
        if (a.j(CustomPaletteBrushScaleDescriptionMetadata.a)) {
            return;
        }
        a.y(CustomPaletteBrushScaleDescriptionMetadata.a);
    };
    CustomPaletteBrushScaleDescriptionMetadata.c = function (a) {
        BrushScaleDescriptionMetadata.c(a);
        a.item("BrushSelectionMode", "ExportedType:string:BrushSelectionMode");
        a.item("BrushSelectionMode@names", "Select;Interpolate");
    };
    CustomPaletteBrushScaleDescriptionMetadata.d = function (a) {
        CustomPaletteBrushScaleDescriptionMetadata.b(a);
        a.aa("CustomPaletteBrushScale", function () { return new CustomPaletteBrushScaleDescription(); });
        a.z("CustomPaletteBrushScale", CustomPaletteBrushScaleDescriptionMetadata.a);
    };
    CustomPaletteBrushScaleDescriptionMetadata.$t = markType(CustomPaletteBrushScaleDescriptionMetadata, 'CustomPaletteBrushScaleDescriptionMetadata');
    CustomPaletteBrushScaleDescriptionMetadata.a = null;
    return CustomPaletteBrushScaleDescriptionMetadata;
}(Base));
export { CustomPaletteBrushScaleDescriptionMetadata };
